// jshint maxerr:1000
/* ---------------------------------------------------------------------------------------------------------

    SCRIBBLEMAKES - ARTIST'S PORTFOLIO WIDGET V1.0
    ----------------------------------------------
    Last updated: 3rd January 2024
    
    ----------------------------------------------
    
    This Source Code Form is subject to the terms of the Mozilla Public
    License, v. 2.0. If a copy of the MPL was not distributed with this
    file, You can obtain one at http://mozilla.org/MPL/2.0/.
    
    ----------------------------------------------
    
    Welcome to the Artist's Portfolio Widget (APW)! This widget builds a portfolio layout for artists,
      making it more accessible for artists with no coding experience. To integrate into your website, 
      save this .js file to it and follow the instructions in the 'more information' link 
      (https://scribblemakes.com/code/development#sc_apw). You will need to fill in the required 
      variables below.
      
    To include this correctly in your web page, you can copy this html code between your <body> tags:
    ---------------------------------------------------------------------------------------- Start HTML Code
    <!-- The container that images are added to -->
    <div id="sc_apw_gallery">
      <noscript>Javascript disabled, portfolio cannot be retrieved</noscript>
    </div>
    
    <!-- Add this at the end of the page to call the script for the portfolio -->
    <script src="scWidget_ArtistsPortfolio.js"></script>
    ------------------------------------------------------------------------------------------ End HTML Code
    
    ----------------------------------------------
    
    /‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾\  Looking for more tutorials, widgets, and plugins?       /‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾\  
   ｜  ❮‾ |\  /|  / ⎡‾‾  ｜  Get them on my personal website:                      ｜  ❮‾ |\  /|  / ⎡‾‾  ｜
   ｜  _❯ | \/ | /  ⎣__  ｜   https://scribblemakes.com/code                       ｜  _❯ | \/ | /  ⎣__  ｜  
    \___________________/                                                          \____________________/ 
    
    ----------------------------------------------
    
    For more information on this script:
     https://scribblemakes.com/code/development#sc_apw
    
--------------------------------------------------------------------------------------------------------- */

// FILL IN ANY VARIABLES BELOW IF YOU WANT TO CHANGE THEM FROM THE DEFAULT

/* Where you enter new images, each image is an array with its URL, ALT (optional), Tags (optional), Title (optional), Description (optional), Date + Hour (optional), Preview image (optional), and link redirect (optional) */
// The IMAGE URL is local, so don't include any '/'. Hours are in 24 hour time
// For example: ["IMAGE.PNG", "ALT", "TAG_1 TAG_2", "TITLE", "DESCRIPTION", "YYYY-MM-DD-HH-MM", "PREVIEW.PNG", "HTTPS://SITE.COM"]
var sc_apw_galleryArray = [
	["basic_Quickstart.png", "An icon representing the Artist's Portfolio Widget.", "First_Steps Quickstart", "Quickstart", 
      `
		<p>This quickstart guide will take you through the fastest steps to get started with this widget. For more indepth instructions, start with the introduction.</p>
		<ol>
			<li style="margin: 0.5em 0">Download the .zip folder from the widget's <a href="https://scribblemakes.com/code/development#sc_apw">development page</a></li>
			<li style="margin: 0.5em 0">Unzip, or extract, the files inside the .zip folder. Keep these files in the same folder when uploading them to web-hosting services.</li>
			<li style="margin: 0.5em 0">Open the .html file (sc_apw_example.html) and delete the additional HTML at the top of the body element.</li>
			<li style="margin: 0.5em 0">Save the .html file and open the folder named "sc_apw_imgs". Upload any images you want to add to your gallery here.</li>
			<li style="margin: 0.5em 0">Open the .js file (scWidget_ArtistsPortfolio.js) and find the variable named "sc_apw_galleryArray"</li>
			<li style="margin: 0.5em 0">Delete everything inside the sc_apw_galleryArray variable except the example .jpg images (i.e. example_6.jpg, example_5.jpg, etc).</li>
			<li style="margin: 0.5em 0">Replace the examples' information with your images' information. The guide for how they're laid out is above the variable, but the order is: <code>Image URL, ALT (optional), Tags (optional), Title (optional), Description (optional), Date + Hour (optional), Preview image (optional), and link redirect (optional)</code></li>
			<li style="margin: 0.5em 0">Save the .js file and view the .html page. If done correctly, you should be able to see your images and their information when you click on them.</li>
		</ol>
	  `,
      "2024-01-01-21-00", "basic_Quickstart_preview.png",
	  "https://scribblemakes.com/code/development#sc_apw"],
	  
	["basic_Introduction.png", "A collection of images cropped together to show the different CSS styles available for the Artist's Portfolio widget.", "First_Steps", "Introduction", 
      `
		<p>Welcome to the Artist's Portfolio, this page is both an example of the portfolio widget and a guide on how to set it up.</p>
		<p>The portfolio is ideal for sites that contain a lot of images, with information, that should be viewed together, like artist portfolios, photography blogs, and catalogues. It allows you, and the user, to customise a lot of the functionality (such as how it's sorted, what images are shown, etc), comes with multiple pre-made styles (as shown in the image), and is completely free to use.</p>
		<p>To get started, head over to the widget's <a href="https://scribblemakes.com/code/development#sc_apw">development page</a> to get the needed files. Then come back here and click on the 'Preparing Your Widget' image to continue.</p>
		<p>(If you're having trouble at any point in this guide, you can ask for help or give feedback through my <a href="https://scribblemakes.com/code">code page</a>.)</p>
	  `,
      "2024-01-01-20-00", "basic_Introduction_preview.png",
	  "https://scribblemakes.com/code/development#sc_apw"],
	  
	["basic_WebpagePrep.png", "A folder directory and a page of HTML code. The directory shows the widget's HTML page, CSS files, Javascript file, and image folder in the same folder. The HTML code shows the example HTML folder with the first lines of code inside the <body> element removed.", "First_Steps HTML", "Preparing your Webpage", 
      `
		<p>After you've downloaded the .zip folder from the widget's <a href="https://scribblemakes.com/code/development#sc_apw">development page</a>, unzip (or extract) the files into the same location. If you did this correctly, opening the <code>.html</code> file will show this guide.</p>
		<p>To get your page prepared, first choose if you're using the example <code>.html</code> file or adding the gallery to your own <code>.html</code> file:</p>
		<details><summary style="text-decoration:underline; cursor:pointer;">Using example <code>.html</code> file</summary>
			<ol>	
				<li style="margin: 0.5em 0">Open the <code>sc_apw_example.html</code> file in your text or code editor of choice. I use <a href="https://neocities.org/">Neocities' code editor</a> and <a href="https://notepad-plus-plus.org/">Notepad++</a>. You can rename the file to whatever you prefer.</li>
				<li style="margin: 0.5em 0">First, choose one of the styles from the dropdown at the top of this page (you can click on the image to close this popup). You'll find a matching <code>.CSS</code> file in the folder you downloaded, copy the name of the file (including the <code>.css</code> extension) and copy it into the <code>&lt;link&gt;</code> line in the <code>&lt;head&gt;</code>. It should look like the following:<br>
				<code>&lt;link href="[REPLACE WITH STYLE FILE NAME]" rel="stylesheet" type="text/css" media="all"&gt;</code><br>
				Note that some styles hide the additional information on smaller screens (mobile). For this guide, it will use the <code>sc_apw_style.css</code> stylesheet.</li>
				<li style="margin: 0.5em 0">To remove the text and dropdown at the top of the page, delete everything between the <code>&lt;body&gt;</code> tag and the comment reading: <code>&lt;!-- ///// Safe to delete everything between this line and the <body> tag ///// --&gt;</code>. Your code should look like the image adjacent.</li>
				<li style="margin: 0.5em 0">Your <code>.html</code> page is now ready to have your images added to it. You can add more HTML, delete the collection boxes, or edit the page however you like as long as the <code>&lt;div id="sc_apw_gallery"&gt;&lt;/div&gt;</code> and <code>&lt;script src="scWidget_ArtistsPortfolio.js" type="text/javascript"&gt;&lt;/script&gt;</code> remain.</li>
			</ol>
		</details>
		<details><summary style="text-decoration:underline; cursor:pointer;">Adding to an existing <code>.html</code> file</summary>
			<ol>	
				<li style="margin: 0.5em 0">Move your files so your <code>.html</code> file is in the same place as the <code>.js</code> and <code>.css</code> files you downloaded. If it's not in the same place, you'll need to add the file directory to any file name you write in your <code>.html</code> file. For example: the <code>&lt;script&gt;</code> element will need you to write <code>[FILE DIRECTORY]/scWidget_ArtistsPortfolio.js</code> for its <code>src</code> rather than just the file's name.</li>
				<li style="margin: 0.5em 0">Open the existing <code>.html</code> file in your text or code editor of choice. I use <a href="https://neocities.org/">Neocities' code editor</a> and <a href="https://notepad-plus-plus.org/">Notepad++</a>.</li>
				<li style="margin: 0.5em 0">Choose one of the styles from the dropdown at the top of this page (you can click on the image to close this popup). You'll find a matching <code>.CSS</code> file in the folder you downloaded, copy the name of the file (including the <code>.css</code> extension) and paste it into the <code>&lt;link&gt;</code> line in the <code>&lt;head&gt;</code> section. It should look like the following:<br>
				<code>&lt;link href="[REPLACE WITH STYLE FILE NAME]" rel="stylesheet" type="text/css" media="all"&gt;</code><br>
				Note that some styles hide the additional information on smaller screens (mobile). For this guide, it will use the <code>sc_apw_style.css</code> stylesheet.<br><br>
				If you have another stylesheet you're using for the page, you can add another <code>&lt;link&gt;</code> line of code beneath the existing line.</li>
				<li style="margin: 0.5em 0">Copy the following code into your <code>.html</code> file between the two <code>&lt;body&gt;</code> tags:
				<code>
					&lt;!-- Creates the image gallery --&gt;
					&lt;div id="sc_apw_gallery"&gt;
						&lt;noscript&gt;Javascript disabled, portfolio cannot be retrieved&lt;/noscript&gt;
					&lt;/div&gt;
					&lt;script src="scWidget_ArtistsPortfolio.js" type="text/javascript"&gt;&lt;/script&gt;
				</code></li>
				<li style="margin: 0.5em 0">Your <code>.html</code> page is now ready to have your images added to it. You can add more HTML, delete the collection boxes, or edit the page however you like as long as the <code>&lt;div id="sc_apw_gallery"&gt;&lt;/div&gt;</code> and <code>&lt;script src="scWidget_ArtistsPortfolio.js" type="text/javascript"&gt;&lt;/script&gt;</code> remain.</li>
			</ol>
		</details>
		<p>Once you've prepared your <code>.html</code> file, open the "Adding your Images" image to continue</p>
	  `,
      "2024-01-01-19-00", "basic_WebpagePrep_preview.png",
	  "https://scribblemakes.com/code/development#sc_apw"],
      
    ["basic_AddingImages.png", "Lines of javascript code showing an array. The array holds multiple sets of information for images and their descriptions.", "First_Steps Images Javascript", "Adding your Images", 
      `<p>Open the <code>scWidget_ArtistsPortfolio.js</code> file with your editor of choice. This is the only file you'll need to edit to add new images.</p>
		<ol>
			<li style="margin: 0.5em 0">If you haven't opened the file before, you'll need to prepare it first. Scroll down to (or <kbd>ctrl</kbd> + <kbd>f</kbd>) the line: <code>var sc_apw_imageFolder = "sc_apw_imgs";</code>. Depending on where your images are, you'll need to change what <code>sc_apw_imageFolder</code> equals:
				<details><summary style="text-decoration:underline; cursor:pointer;">Images are from different websites or are in different folders</summary>
					<p><code>var sc_apw_imageFolder="";</code> and when you input images, you'll include their full absolute URL <i>or</i> their relative URL from your root folder.</p>
				</details>
				<details><summary style="text-decoration:underline; cursor:pointer;">You're adding the gallery or collections to multiple <code>.html</code> pages</summary>
					<p><code>var sc_apw_imageFolder="";</code> and when you input images, you'll include their full absolute URL <i>or</i> their relative URL from your root folder.</p>
				</details>
				<details><summary style="text-decoration:underline; cursor:pointer;">Images are inside the <code>sc_apw_imgs</code> and in the same folder as the <code>.html</code> file</summary>
					<p><code>var sc_apw_imageFolder="[URL TO FOLDER NAME]";</code> and when you input images you'll only include its file name and file type extension. The URL should be relative to your webpage, so if you don't change the default folders it will be <code>var sc_apw_imageFolder = "sc_apw_imgs";</code>.</p>
				</details>
			</li>
			<li style="margin: 0.5em 0">Scroll to (or <kbd>ctrl</kbd> + <kbd>f</kbd>) the line: <code>var sc_apw_galleryArray = [</code>, this is the array you'll always add images to. It starts out with pre-added images (they create this guide) which you'll need to delete to make your own gallery. When cleared, the line should read: <code>var sc_apw_galleryArray = [];</code></li>
			<li style="margin: 0.5em 0">To add a new image: start with adding <code>[ ]</code> inside <code>sc_apw_galleryArray</code>, this is the container for the image's information. It should look like this: <code>var sc_apw_galleryArray = [ [ ] ];</code>.</li>
			<li style="margin: 0.5em 0">The image's filename is the only <i>required</i> information you need for the image to appear in the gallery, but it's recommended to add, at least, the image's ALT.<br>
			In the order below, add the following items inside your brackets. Make sure each item is surrounded by <code>"</code>'s, there's a comma between each piece of information, and if you want to skip any: leave them as <code>""</code>. An example of a finished image entry, with all elements, would be:<br> <code>
				["example_6.jpg", "A painting depicting 5 kittens playing in a sideways basket.", "Example", "Example 6",
				"&lt;p&gt;This is the description for example_6.jpg. You can add anything here, including more images.&lt;/p&gt;
				&lt;img src="sc_apw_imgs/example_7.jpg"&gt;
				&lt;p&gt;This example has the image's ALT, tags, title, description, date, and a preview image.&lt;/p&gt;",
				"2024-01-01-10-00", "example_7.jpg"]
			</code><br>
			You can see more in the <code>.js</code> file before emptying the <code>sc_apw_galleryArray</code> array.</li>
			<ol>
				<li><b>Filename</b>, the full name of your file including the file type. For example: <code>"image.png"</code>. The script automatically adds your <code>sc_apw_imageFolder</code> variable in front of it, so if you're getting it from another website write it as: <code>https://[SITE URL]/image.png</code></li>
				<li><b>ALT</b>, the text that appears if an image can't be loaded or is read by a screen reader. This describes the image's appearance.</li>
				<li><b>Tags</b>, categories the image falls into that can be used by you, or the user, to sort your gallery. Each tag is separated by a space, and spaces inside a tag (such as: First Steps) are made using the <kbd>_</kbd> character (such as: First_Steps). Tags are case insensitive, and will use the first iteration of the tag for reference on uppercase and lowercase characters.</li>
				<li><b>Tags</b>, categories the image falls into that can be used by you, or the user, to sort your gallery. Each tag is separated by a space, and spaces inside a tag (such as: First Steps) are made using the <kbd>_</kbd> character (such as: First_Steps). Tags are case insensitive, and will use the first iteration of the tag for reference on uppercase and lowercase characters.</li>
				<li><b>Title</b>, the title of the image, which will be used to sort the gallery alphabetically and appear in the image's information.</li>
				<li><b>Description</b>, the description of the image. It is written as HTML and appears in the image's information.</li>
				<li><b>Date</b>, a date assigned to the image. It's used to sort the gallery chronologically and is written as <code>YYYY-MM-DD-HH-MM</code> in 24hr time. For example, an image made on the 10th of January, at 6:30pm, in 2010 would be written as: <code>2010-01-10-18-30</code>.</li>
				<li><b>Preview</b>, a preview image shown in the gallery rather than the original image. The original image is shown when the preview is clicked on. It's recommended to use images with a smaller file size so the page loads more quickly, i.e. the page will load the smaller previews and only load the large original images when the user selects them.</li>
				<li><b>Link Redirect</b>, a link that's displayed in the image's information. This can be useful for advertising other webpages or connecting to another place you've posted the image.</li>
			</ol>
			<li style="margin: 0.5em 0">Once you've added an image, check your webpage to make sure it worked correctly. If you'd like to add more images, repeat step 4 but make sure there's a comma between your image information sets. For example: <code>["image.png"] ["image1.png"]</code> is incorrect, but <code>["image.png"], ["image1.png"]</code> is correct.</li>
		</ol>
		`, 
      "2024-01-01-18-00", "basic_AddingImages_preview.png",
	  "https://scribblemakes.com/code/development#sc_apw"],
      
    ["inter_GalleryCustom.png", "Lines of javascript code showing a collection of variables. The variables are different settings for the artist's portfolio widget.", "CSS Intermediate Javascript", "Gallery Customisation", 
		`<p>There are two ways to customise your gallery: through CSS and through javascript. The CSS file affects the visuals of the gallery, while the javascript affects how it functions, different examples of CSS are already visible by swapping the style at the top of the page.</p>
	  
		<details><summary style="text-decoration:underline; cursor:pointer;">Editing the CSS file</summary>
			<p>A list of the elements you can change are below:</p>
			<ul style="word-break: break-word;">
				<li><b>.sc_apw_collectionGallery</b>, the main container for a collection gallery</li>
				<li><b>.sc_apw_collectionGallery_imageEnlarge</b>, images inside collections or image descriptions that are clicked on.</li>
				<br>
				
				<li><b>#sc_apw_galleryInteractionBar</b>, the main container for all of the user inputs (sort options, tag filtering, and the search bar)</li>
				<li><b>#sc_apw_userInteract_sortTags</b>, the container holding the tags</li>
				<li><b>.sc_apw_tagButton_included</b>, tags that are included in the search</li>
				<li><b>.sc_apw_tagButton_excluded</b>, tags that are excluded in the search</li>
				<li><b>#sc_apw_userInteract_sortOrder</b>, the container for chronological and alphabetical sort options</li>
				<li><b>#sc_apw_userInteract_sortOrder_object</b>, the input box for the sort options</li>
				<li><b>#sc_apw_userInteract_search</b>, the container for the search options</li>
				<li><b>#sc_apw_userSearch_date_container</b>, the container for the 'posted on date' label and input</li>
				<li><b>#sc_apw_userSearch_dateAfter_container</b>, the container for the 'posted after date' label and input</li>
				<li><b>#sc_apw_userSearch_dateBefore_container</b>, the container for the 'posted before date' label and input</li>
				<li><b>#sc_apw_userSearch_categoryText_container</b>, the container for the search category and input bar</li>
				<li><b>#sc_apw_userSearch_submit</b>, the submit button</li>
				<li><b>#sc_apw_userSearch_reset</b>, the reset button</li>
				<br>
				
				<li><b>#sc_apw_gallery</b>, the main container for the gallery images</li>
				<li><b>#sc_apw_emptyGalleryText</b>, the text that appears when no images are visible</li>
				<br>
				
				<li><b>#sc_apw_imageViewer</b>, the main container for viewing gallery images</li>
				<li><b>#sc_apw_imageViewerBox</b>, the container for the image and gallery left & right arrows</li>
				<li><b>.sc_apw_imageViewerBox_Full</b>, class given if the image has no information</li>
				<li><b>#sc_apw_imageHolder</b>, the container for the image, uses the image as a background-image URL</li>
				<li><b>.sc_apw_galleryButton</b>, the left and right buttons on the image viewer</li>
				<li><b>.sc_apw_galleryButton_disabled</b>, the image viewer buttons when disabled</li>
				<li><b>#sc_apw_galleryPrev</b>, the 'previous image' button</li>
				<li><b>#sc_apw_galleryNext</b>, the 'next image' button</li>
				<li><b>#sc_apw_textHolder</b>, the container for the image's information button</li>
				<li><b>#sc_apw_textHolder_title</b>, the image's title</li>
				<li><b>#sc_apw_textHolder_date</b>, the image's date</li>
				<li><b>#sc_apw_textHolder_tags</b>, the image's tags</li>
				<li><b>#sc_apw_textHolder_description</b>, the image's description</li>
				<li><b>#sc_apw_textHolder_linkRedirect</b>, the image's external/redirect link</li>
			</ul>
		</details>
	  
		<details><summary style="text-decoration:underline; cursor:pointer;">Editing the Javascript file</summary>
			<p>Every setting in the javascript file is labelled with what it does and how to change it. If you're not familiar with javascript, remember these rules to changing variables:</p>
			<p><b>Text</b> is included inside quotation marks. For example, to change <code>sc_apw_devSortOrder</code> to the text "Next Image", it would be: <code>var sc_apw_devSortOrder = "Next Image";</code></p>
			<p><b>Numbers</b> are written without additions. For example, to change <code>sc_apw_galleryRowAmount</code> to the number "5", it would be: <code>var sc_apw_galleryRowAmount = 5;</code></p>
			<p><b>True or False</b> are written without additions and in lowercase. For example, to change <code>sc_apw_previewImages</code> to "false", it would be: <code>var sc_apw_previewImages = false;</code></p>
		</details>
		`, 
      "2024-01-01-17-00", "inter_GalleryCustom_preview.png",
	  "https://scribblemakes.com/code/development#sc_apw"],
      
    ["inter_CollectionGalleries.png", "Two collection galleries showing images with the tag 'First Steps' and the tag 'Example' respectively.", "Intermediate HTML", "Collection Galleries", 
		`
			<p>Collection galleries are elements you can add to your pages that only display images with a tag you choose, like the boxes at the top of this page showing the 'First Steps' and 'Example' images.</p>
			<p>To make one yourself, you create a <code>&lt;div&gt;</code> element with the class: "<code>sc_apw_collectionGallery</code>" and give it an <code>id</code> starting with "<code>sc_apw_collectionGallery=</code>". The <code>id</code> will end with what tag you want to display, replacing spaces with underscores (<kbd>_</kbd>).</p>
			<p>For example, the 'First Steps' collection gallery above looks like:</p>
			<code style="word-break: break-word;">
				&lt;div id="sc_apw_collectionGallery=First_Steps" class="sc_apw_collectionGallery"&gt;<br>
				&lt;/div&gt;
			</code>
			<p>You can then put <code>HTML</code> inside that, and the images will appear at the bottom. The collection galleries at the top of this page have <code>&lt;h2&gt;</code> elements inside it, as an example.</p>
			<p>If you're putting collection galleries on other pages, make sure your <code>sc_apw_imageFolder</code> variable is set to <code>""</code> in your javascript file, and all of your images are linked to correctly.</p>
		`, 
      "2024-01-01-16-00", "inter_CollectionGalleries_preview.png",
	  "https://scribblemakes.com/code/development#sc_apw"],
      
	  
	  
		
    ["example_6.jpg", "A painting depicting 5 kittens playing in a sideways basket.", "Example", "Example 6",
		`<p>This is the description for example_6.jpg. You can add anything here, including more images.</p>
		<img src="sc_apw_imgs/example_7.jpg">
		<p>This example has the image's ALT, tags, title, description, date, and a preview image.</p>`,
		"2024-01-01-10-00", "example_7.jpg"],
		
    ["example_5.jpg", "A painting depicting 5 kittens playing on the top of a piano.", "Example", "Example 5",
		`<p>This is the description for example_5.jpg. You can add anything here, including more images.</p>
		<img src="sc_apw_imgs/example_5.jpg">
		<p>This example has the image's ALT, tags, title, description, and a date.</p>`,
		"2024-01-01-09"],
		
    ["example_4.jpg", "A painting depicting 2 kittens playing sitting and laying inside an open case.", "Example", "Example 4",
		`<p>This is the description for example_4.jpg. You can add anything here, including more images.</p>
		<img src="sc_apw_imgs/example_4.jpg">
		<p>This example has the image's ALT, tags, title, and a description.</p>`],
	
    ["example_3.jpg", "A painting depicting many kittens playing in some hay.", "Example", "Example 3"],
	
    ["example_2.jpg", "A painting depicting 5 cats smoking cigars and drinking at a white table. The centre cat is wearing a monocle and looks shocked.", "Example"],
		
    ["example_1.jpg", "A painting depicting 7 cats playing instruments as if in a band. The centre cat is faced away from the viewer and acting as the conductor."]
  ];

/* IMAGE FOLDER AND HOMEPAGE */
var sc_apw_imageFolder = "sc_apw_imgs"; 
			// Filepath to your images from your page, i.e. which folder your images are in compared to your webpage (.html).
			
			// Leave sc_apw_imageFolder as "" if you're using absolute URLs for images, i.e. "https://[YOUR-SITE-NAME].[DOMAIN]/scWidget_ArtistsPortfolio/sc_apw_imgs/image.png"
			
			// If your .js file isn't finding the folder correctly, or you want to show your gallery/collections on multiple pages, change it to start at your root or into an absolute URL, i.e. "/scWidget_ArtistsPortfolio/sc_apw_imgs" -OR- "https://site.com/scWidget_ArtistsPortfolio/sc_apw_imgs respectively"


/* IMAGE CSS AND DISPLAY */
var sc_apw_previewImages = true; // Use preview images, provided by the array, in the grid gallery
var sc_apw_galleryRowAmount = 4;  // How many images are displayed in a row, minimum 1 per row
var sc_apw_galleryMobileRowAmount = 2;  // How many images are displayed in a row on thin screens, minimum 1 per row
var sc_apw_galleryRowCSSCorrection = true; // Do images resize to fill a row if there aren't enough
var sc_apw_CSSMobileWidth = '600px';  // What screen width triggers mobile sizing for the gallery images

var sc_apw_gallery_showInfo = true; // Show title, description, date, etc when images are open
  var sc_apw_gallery_showTitle = true; // Show title in image description
  var sc_apw_gallery_showDate = true; // Show date in image description
  var sc_apw_gallery_showTags= true; // Show tags in image description
  var sc_apw_gallery_showDescription = true; // Show description in image description
  var sc_apw_gallery_descriptionImgs_clickable = true; // Can images in the description be clicked on to make them bigger

var sc_apw_hideScheduled = true;  // Hide images with dates set in the future
var sc_apw_devSortOrder = "newest";  // What order the images are displayed in (value is first): "auto", "newest", "oldest", "alphabet asc", and "alphabet desc"

var sc_apw_emptyGalleryText = "No images match your search terms"; // What text displays if the gallery is empty


/* IMAGE GALLERY INTERACTION */
var sc_apw_gallery_multipleImage = true;  // Can you navigate between the images while fullscreen
var sc_apw_gallery_fullpageLinkRedirect = false;  // If the image has a link redirect, does clicking on it open a new page (true) or is there a visible link in its description (false)

var sc_apw_userChange_search = true; // Can the user use a search bar
	var sc_apw_searchElement_dateOnText = "Show images on: "; // The text that appears before 'date of' search
	var sc_apw_searchElement_dateAfterText = "Show images after: "; // The text that appears before 'date after' search
	var sc_apw_searchElement_dateBeforeText = "Show images before: "; // The text that appears before 'date before' search
	var sc_apw_searchElement_categoryText = "Search by: "; // The text that appears before the search category
	var sc_apw_searchElement_searchText = "Search for: "; // The text that appears before the search bar
	var sc_apw_searchElement_submitText = "Date & Search"; // The text shown on the search button
	var sc_apw_searchElement_resetText = "Reset"; // The text shown on the reset button

var sc_apw_userChange_sortOrder = true; // Can the user change the chronological sort
	var sc_apw_userChange_sortOrderText = "Sort by: "; // The text that appears before sort order dropdown

var sc_apw_userChange_sortTags = true; // Can the user sort the gallery with tags
	var sc_apw_devSortTagsOrder = "alpha desc";  // What order the tags are displayed in (value is first): "auto", "newest", "oldest", "alphabet asc", and "alphabet desc"


/* DATES AND TIMES */
// Setting the correct timezone for dates
var sc_apw_timezone = +10;  // What your timezone is compared to UTC, for example: AEST is UTC+10
var sc_apw_defaultTime = "2024-01-01-08";  // What images have their time set to as default, if not assigned
var sc_apw_settingImageFormat_Date = "Posted on MML DDTH, YYYY at HHS:MINXM"; // Formats the date on images
  // Date format below, leave variable empty to hide date
  /*  MML = Long Month (January), MMS = Short Month (Jan), MM = Number Month (01)
      DDTH = Day with th (1st), DDN = Day name (Monday), DDS = Day name short (Mon), DD = Day number (01)
      YY = Short year (87), YYYY = Long year (1987)
      HH = Hour in 24hr time (0-23), HHS = Hour in 12hr time (1-12)
      MIN = Minutes (00)
      XM = Am / Pm  */


/* GALLERY COLLECTIONS */
var sc_apw_collectionLink = "#sc_apw_gallery"; // When clicking on an image in the collection, it opens this URL. If left as "" then the image enlargens instead.
var sc_apw_collectionClass = "sc_apw_collectionGallery";
var sc_apw_collectionSortOrder = "newest";  // What order the tags are displayed in (value is first): "auto", "newest", "oldest", "alphabet asc", and "alphabet desc"


/* PLUGIN COMPATIBILITY */
const sc_apw_icep_ignoreClass = "sc_icep_noEnlarge"; // Click to Enlarge Plugin, ignores images with this class

// ---------------------------------------------------------------------------------------------------------
// ---------------------- DO NOT EDIT PAST THIS POINT UNLESS PROFICIENT IN JAVASCRIPT ----------------------
// ---------------------------------------------------------------------------------------------------------

// ---------------------------------
// --- CORRECT IMAGE FOLDER LINK ---
// ---------------------------------
if (!sc_apw_imageFolder.endsWith("/") && sc_apw_imageFolder!="") {sc_apw_imageFolder += "/";}


// --------------------------------
// -- CORRECT DATES FOR TIMEZONE --
// --------------------------------
  // Correct time and date to match the viewer's timezone
  var sc_apw_imageDateText = "";
  var sc_apw_imageDate;
  for (sc_apw_i = 0; sc_apw_i < sc_apw_galleryArray.length; sc_apw_i++) {
    // Add a date in if it doesn't have one
    if(!sc_apw_galleryArray[sc_apw_i][5] || sc_apw_galleryArray[sc_apw_i][5] == "") {
      sc_apw_galleryArray[sc_apw_i][5] = "";
    } else {
      sc_apw_imageDateText = sc_apw_galleryArray[sc_apw_i][5].split("-"); // Date text
        // Replace any missing dates and times if not provided, a year is REQUIRED
        if (!sc_apw_imageDateText[1]) {sc_apw_imageDateText[1] = "01";}  // Month
        if (!sc_apw_imageDateText[2]) {sc_apw_imageDateText[2] = "01";}  // Day
        if (!sc_apw_imageDateText[3]) {sc_apw_imageDateText[3] = "00";}  // Hour
        if (!sc_apw_imageDateText[4]) {sc_apw_imageDateText[4] = "00";}  // Minute
      sc_apw_imageDate = new Date(Date.UTC(sc_apw_imageDateText[0], sc_apw_imageDateText[1]-1, sc_apw_imageDateText[2], sc_apw_imageDateText[3], sc_apw_imageDateText[4], 0));  // Date object
      sc_apw_imageDate = new Date(sc_apw_imageDate - (sc_apw_timezone * 60 * 60000)); // Correct for timezone
      sc_apw_galleryArray[sc_apw_i][5] = sc_apw_imageDate;
    }
  }
  
  
// -----------------------------------
// -------- SORTING FUNCTIONS --------
// -----------------------------------
var sc_apw_sortOrder = sc_apw_devSortOrder;

  // Set default date to actual date
  sc_apw_defaultTime = sc_apw_defaultTime.split("-"); // Date text
    // Replace any missing dates and times if not provided, a year is REQUIRED
    if (!sc_apw_defaultTime[1]) {sc_apw_defaultTime[1] = "01";}  // Month
    if (!sc_apw_defaultTime[2]) {sc_apw_defaultTime[2] = "01";}  // Day
    if (!sc_apw_defaultTime[3]) {sc_apw_defaultTime[3] = "00";}  // Hour
    if (!sc_apw_defaultTime[4]) {sc_apw_defaultTime[4] = "00";}  // Minute
  sc_apw_defaultTime = new Date(Date.UTC(sc_apw_defaultTime[0], sc_apw_defaultTime[1]-1, sc_apw_defaultTime[2], sc_apw_defaultTime[3], sc_apw_defaultTime[4], 0));  // Date object
  sc_apw_defaultTime = new Date(sc_apw_defaultTime - (sc_apw_timezone * 60 * 60000)); // Correct for timezone
  
// Sort by chronological order
var sc_apw_tempDateObjectA = sc_apw_defaultTime;
var sc_apw_tempDateObjectB = sc_apw_defaultTime;
function sc_apw_SortDates(sc_apw_a, sc_apw_b) {
  if (sc_apw_a[5] != "" && sc_apw_a[5]) {sc_apw_tempDateObjectA = sc_apw_a[5];}
    else {sc_apw_tempDateObjectA = sc_apw_defaultTime}
  if (sc_apw_b[5] != "" && sc_apw_b[5]) {sc_apw_tempDateObjectB = sc_apw_b[5];}
    else {sc_apw_tempDateObjectB = sc_apw_defaultTime}
  
  if (sc_apw_sortOrder == "oldest") {
    return sc_apw_tempDateObjectA - sc_apw_tempDateObjectB;
  } else if (sc_apw_sortOrder == "newest") {
    return sc_apw_tempDateObjectB - sc_apw_tempDateObjectA;
  }
}

// Sort by Alphabetical order
var sc_apw_tempAlphaObjectA = sc_apw_defaultTime;
var sc_apw_tempAlphaObjectB = sc_apw_defaultTime;
function sc_apw_SortAlpha(sc_apw_a, sc_apw_b) {
  if (sc_apw_a[3] != "" && sc_apw_a[3]) {sc_apw_tempAlphaObjectA = sc_apw_a[3];}
    else {sc_apw_tempAlphaObjectA = "zzzzzzzzzzzzzzzzzz";}
  
  if (sc_apw_b[3] != "" && sc_apw_b[3]) {sc_apw_tempAlphaObjectB = sc_apw_b[3];}
    else {sc_apw_tempAlphaObjectB = "zzzzzzzzzzzzzzzzzz";}
  
  if (sc_apw_sortOrder == "alpha desc") {
    if (sc_apw_tempAlphaObjectA < sc_apw_tempAlphaObjectB) {return 1;} 
    else {return -1;}
  } else if (sc_apw_sortOrder == "alpha asc") {
    if (sc_apw_tempAlphaObjectA < sc_apw_tempAlphaObjectB) {return -1;} 
    else {return 1;}
  }
}
  

// -----------------------------------
// ----------- TAG SORTING -----------
// -----------------------------------
// Tag inclusion and exclusion lists
var sc_apw_allTags = [];
var sc_apw_lowerTags = [];
var sc_apw_includeTags = [];
var sc_apw_excludeTags = [];
var sc_apw_tempImageTags = [];
var sc_apw_tempRegexTags = "";

// Make tag list
if (sc_apw_userChange_sortTags) {
	for (sc_apw_i = 0; sc_apw_i < sc_apw_galleryArray.length; sc_apw_i++) {
		if (sc_apw_galleryArray[sc_apw_i][2] && sc_apw_galleryArray[sc_apw_i][2] != "") {
			sc_apw_tempImageTags = sc_apw_galleryArray[sc_apw_i][2].split(" ");
			for (sc_apw_ii = 0; sc_apw_ii < sc_apw_tempImageTags.length; sc_apw_ii++) {
				// Replace any _ characters 
				sc_apw_tempImageTags[sc_apw_ii] = sc_apw_tempImageTags[sc_apw_ii].replaceAll("_", " ");
				// Check if tag is already catalogued
				if (sc_apw_lowerTags.indexOf(sc_apw_tempImageTags[sc_apw_ii].toLowerCase()) < 0) {
					sc_apw_lowerTags.push(sc_apw_tempImageTags[sc_apw_ii].toLowerCase());
					sc_apw_allTags.push(sc_apw_tempImageTags[sc_apw_ii]);
				} else {
					// Fixes any tags to match their first iteration
					sc_apw_tempImageTags[sc_apw_ii] = sc_apw_allTags[sc_apw_lowerTags.indexOf(sc_apw_tempImageTags[sc_apw_ii].toLowerCase())];
				}
				// Return any _ characters 
				sc_apw_tempImageTags[sc_apw_ii] = sc_apw_tempImageTags[sc_apw_ii].replaceAll(" ", "_");
			}
			// Update image's tags
			sc_apw_galleryArray[sc_apw_i][2] = sc_apw_tempImageTags.join(" ");
		}
	}
	// Sort tags
	switch (sc_apw_devSortTagsOrder) {
		case "newest":
			sc_apw_allTags.reverse();
			sc_apw_lowerTags.reverse();
			break;
		case "alpha asc":
			sc_apw_allTags.sort(sc_apw_SortTagsAlpha);
			sc_apw_lowerTags.sort(sc_apw_SortTagsAlpha);
			break;
		case "alpha desc":
			sc_apw_allTags.sort(sc_apw_SortTagsAlpha);
			sc_apw_lowerTags.sort(sc_apw_SortTagsAlpha);
			break;
	}
}

// Sort tag list order function
function sc_apw_SortTagsAlpha(sc_apw_a, sc_apw_b) {
  if (sc_apw_a != "" && sc_apw_a) {sc_apw_tempAlphaObjectA = sc_apw_a;}
    else {sc_apw_tempAlphaObjectA = "zzzzzzzzzzzzzzzzzz";}
  
  if (sc_apw_b != "" && sc_apw_b) {sc_apw_tempAlphaObjectB = sc_apw_b;}
    else {sc_apw_tempAlphaObjectB = "zzzzzzzzzzzzzzzzzz";}
  
  if (sc_apw_devSortTagsOrder == "alpha desc") {
    if (sc_apw_tempAlphaObjectA < sc_apw_tempAlphaObjectB) {return 1;} 
    else {return -1;}
  } else if (sc_apw_devSortTagsOrder == "alpha asc") {
    if (sc_apw_tempAlphaObjectA < sc_apw_tempAlphaObjectB) {return -1;} 
    else {return 1;}
  }
}

// Add and remove tags from display list function
function sc_apw_TagListEdit(sc_apw_tempTagObject) {
	var sc_apw_tempTagName = sc_apw_tempTagObject.innerText;
	if (sc_apw_includeTags.indexOf(sc_apw_tempTagName) > -1) {
		sc_apw_includeTags.splice(sc_apw_includeTags.indexOf(sc_apw_tempTagName), 1);
		sc_apw_tempTagObject.classList.remove("sc_apw_tagButton_included");
		sc_apw_excludeTags.push(sc_apw_tempTagName);
		sc_apw_tempTagObject.classList.add("sc_apw_tagButton_excluded");
	} else if (sc_apw_excludeTags.indexOf(sc_apw_tempTagName) > -1) {
		sc_apw_excludeTags.splice(sc_apw_includeTags.indexOf(sc_apw_tempTagName), 1);
		sc_apw_tempTagObject.classList.remove("sc_apw_tagButton_excluded");
	} else {
		sc_apw_includeTags.push(sc_apw_tempTagName);
		sc_apw_tempTagObject.classList.add("sc_apw_tagButton_included");
	}
	sc_apw_AddImages();
}

// Filter images based on tags function
function sc_apw_TagFilter(sc_apw_tempImageArrayItem) {
	var sc_apw_tempImageTags = sc_apw_tempImageArrayItem[2].split(" ");
	for (sc_apw_ti=0; sc_apw_ti<sc_apw_tempImageTags.length; sc_apw_ti++) {
		sc_apw_tempImageTags[sc_apw_ti] = sc_apw_tempImageTags[sc_apw_ti].replaceAll("_", " ");
		if (sc_apw_excludeTags.indexOf(sc_apw_tempImageTags[sc_apw_ti]) > -1) {
			return false;
		}
	}
	if (sc_apw_includeTags.length > 0) {
		for (sc_apw_ti=0; sc_apw_ti<sc_apw_includeTags.length; sc_apw_ti++) {
			if (sc_apw_tempImageTags.indexOf(sc_apw_includeTags[sc_apw_ti]) < 0) {
				return false;
			}
		}
	}
	return true;
}
  


// ----------------------------------
// -------- SEARCH FUNCTIONS --------
// ----------------------------------
function sc_apw_SearchGallery(sc_apw_tempImageArray) {
	// Check if date exists or reverts to default
	var sc_apw_tempSearchImageDate = "";
	if (!sc_apw_tempImageArray[5] || sc_apw_tempImageArray[5]=="") {
		sc_apw_tempSearchImageDate = sc_apw_defaultTime;
	} else {
		sc_apw_tempSearchImageDate = sc_apw_tempImageArray[5];
	}
	
	// Reformat date into usable string
	sc_apw_tempSearchImageDate =
		sc_apw_tempSearchImageDate.getFullYear().toString() +
		("00" + (sc_apw_tempSearchImageDate.getMonth() + 1)).toString().slice(-2) +
		("00" + sc_apw_tempSearchImageDate.getDate()).toString().slice(-2);
	
	// Check if any search terms are available
	if (sc_apw_searchElement_dateOn.value=="" && sc_apw_searchElement_dateBefore.value=="" && sc_apw_searchElement_dateAfter.value=="" && sc_apw_searchElement_searchTerms.value=="") {
		return true;
	}
	
	// Go through date terms and return false for any incorrect matches
	if (sc_apw_searchElement_dateOn.value!="") {	// Current Date check
		if (sc_apw_tempSearchImageDate == sc_apw_searchElement_dateOn.value.replaceAll("-","")) {
			return true;
		} else {return false}
	} else if (sc_apw_searchElement_dateAfter.value!="") {	// After Date check
		if (parseInt(sc_apw_tempSearchImageDate) <= parseInt(sc_apw_searchElement_dateAfter.value.replaceAll("-",""))) {
			return false;
		}
	} else if (sc_apw_searchElement_dateBefore.value!="") {	// Before Date check
		if (parseInt(sc_apw_tempSearchImageDate) >= parseInt(sc_apw_searchElement_dateBefore.value.replaceAll("-",""))) {
			return false;
		}
	}
	
	// Reference the search bar and category
	if (sc_apw_searchElement_searchTerms.value=="") {
		return true;
	} else {
		switch (sc_apw_searchElement_category.value) {
			case "title":
				if (sc_apw_tempImageArray[3] && sc_apw_tempImageArray[3]!="" && sc_apw_tempImageArray[3].toLowerCase().match(sc_apw_searchElement_searchTerms.value.toLowerCase())) {
					return true;
				} else {return false};
				break;
			case "description":
				if (sc_apw_tempImageArray[4] && sc_apw_tempImageArray[4]!="" && sc_apw_tempImageArray[4].toLowerCase().match(sc_apw_searchElement_searchTerms.value.toLowerCase())) {
					return true;
				} else {return false};
				break;
			case "alt":
				if (sc_apw_tempImageArray[1] && sc_apw_tempImageArray[1]!="" && sc_apw_tempImageArray[1].toLowerCase().match(sc_apw_searchElement_searchTerms.value.toLowerCase())) {
					return true;
				} else {return false};
				break;
		}
	}
	
	// Catch if no search terms are triggered
	return true;
}



// ---------------------------------
// ----- ADD COLLECTION IMAGES -----
// ---------------------------------
var sc_apw_collectionArray = document.getElementsByClassName(sc_apw_collectionClass);
var sc_apw_currentCollectionTag = "";
var sc_apw_currentCollectionArray = [];
var sc_apw_currentCollectionImage;
var sc_apw_currentCollectionImageArray = [];
var sc_apw_tempCollectionSortHolder = sc_apw_sortOrder;

if(sc_apw_collectionArray.length > 0) {
	for (sc_apw_i=0; sc_apw_i<sc_apw_collectionArray.length; sc_apw_i++) {
		// Make sure collection class name is properly formatted
		if (sc_apw_collectionArray[sc_apw_i].id.split("=").length > 1 && sc_apw_collectionArray[sc_apw_i].id.split("=")[1]!="") {
			// Get tag and make it needed for display
			sc_apw_currentCollectionTag = sc_apw_collectionArray[sc_apw_i].id.split("=")[1].replaceAll("_", " ");
			sc_apw_includeTags.push(sc_apw_currentCollectionTag);
			
			// Temporary collection image array
			sc_apw_currentCollectionArray = [];
			for (sc_apw_ii=0; sc_apw_ii<sc_apw_galleryArray.length; sc_apw_ii++) {
				sc_apw_currentCollectionArray.push(sc_apw_galleryArray[sc_apw_ii]);
			}
			sc_apw_currentCollectionImageArray = [];
			// Sort image array IF a valid sort order
			sc_apw_sortOrder = sc_apw_collectionSortOrder;
			switch (sc_apw_sortOrder) {
			  case "newest":
				sc_apw_currentCollectionArray.sort(sc_apw_SortDates);
				break;
			  case "oldest":
				sc_apw_currentCollectionArray.sort(sc_apw_SortDates);
				break;
			  case "alpha asc":
				sc_apw_currentCollectionArray.sort(sc_apw_SortAlpha);
				break;
			  case "alpha desc":
				sc_apw_currentCollectionArray.sort(sc_apw_SortAlpha);
				break;
			}
			sc_apw_sortOrder = sc_apw_tempCollectionSortHolder;
			
			// If image schedule's true, hide images that are set in the future
			if (sc_apw_hideScheduled) {
			  for (sc_apw_ii=0; sc_apw_ii < sc_apw_currentCollectionArray.length; sc_apw_ii++) {
				if ((new Date() < sc_apw_currentCollectionArray[sc_apw_ii][5])) {
				  sc_apw_currentCollectionArray.splice(sc_apw_ii, 1);
				  sc_apw_ii -= 1;
				}
			  }
			}
			// Filter tags
			for (sc_apw_ii=0; sc_apw_ii<sc_apw_currentCollectionArray.length; sc_apw_ii++) {
				if (!sc_apw_currentCollectionArray[sc_apw_ii][2] || sc_apw_currentCollectionArray[sc_apw_ii][2]=="") {
				  sc_apw_currentCollectionArray.splice(sc_apw_ii, 1);
				  sc_apw_ii -= 1;
				} else if (!sc_apw_TagFilter(sc_apw_currentCollectionArray[sc_apw_ii])) {
				  sc_apw_currentCollectionArray.splice(sc_apw_ii, 1);
				  sc_apw_ii -= 1;
				}
			}
			
			// Display images
			for (sc_apw_ii=0; sc_apw_ii < sc_apw_currentCollectionArray.length; sc_apw_ii++) {
				sc_apw_currentCollectionImage = document.createElement("img");
				// Add a class so the click to enlarge plugin ignores these images 
				sc_apw_currentCollectionImage.classList.add(sc_apw_icep_ignoreClass);
				// Image URLs to src
				if (sc_apw_previewImages && sc_apw_currentCollectionArray[sc_apw_ii][6] && sc_apw_currentCollectionArray[sc_apw_ii][6] != "") {
				  sc_apw_currentCollectionImage.src = sc_apw_imageFolder + sc_apw_currentCollectionArray[sc_apw_ii][6];
				} else {
				  sc_apw_currentCollectionImage.src = sc_apw_imageFolder + sc_apw_currentCollectionArray[sc_apw_ii][0];
				}
				// Image ID for enlargen class
				sc_apw_currentCollectionImage.id = "sc_apw_collectionEnlargenID_" + sc_apw_imageFolder +sc_apw_currentCollectionArray[sc_apw_ii][0];
				// Image ALT
				if (sc_apw_currentCollectionArray[sc_apw_ii][1] && sc_apw_currentCollectionArray[sc_apw_ii][1] != "") {sc_apw_currentCollectionImage.alt = sc_apw_currentCollectionArray[sc_apw_ii][1];}
				// Image Title
				if (sc_apw_currentCollectionArray[sc_apw_ii][3] && sc_apw_currentCollectionArray[sc_apw_ii][3] != "") {sc_apw_currentCollectionImage.title = sc_apw_currentCollectionArray[sc_apw_ii][3];}
				// Add elements to HTML page
				sc_apw_collectionArray[sc_apw_i].appendChild(sc_apw_currentCollectionImage);
				sc_apw_currentCollectionImage.tabIndex = 0;
				// Add img element to clickable image array
				sc_apw_currentCollectionImageArray.push(sc_apw_currentCollectionImage);
			}

			// Give all images an onclick and onkeydown function
			var sc_apw_tempEnlargenIDHolder = "";
			sc_apw_currentCollectionImageArray.forEach(img => {
				img.addEventListener('click', function() {
					if (!sc_apw_collectionLink || sc_apw_collectionLink=="") {
						this.classList.toggle("sc_apw_collectionGallery_imageEnlarge");
						sc_apw_tempEnlargenIDHolder = "sc_apw_collectionEnlargenID_" + this.src;
						this.src = this.id.split("sc_apw_collectionEnlargenID_")[1];
						this.id = sc_apw_tempEnlargenIDHolder;
					} else {window.open(sc_apw_collectionLink, "_self");}
				});
				img.addEventListener('keydown', function(e) {
					if (e.keyCode == 13) {
						if (!sc_apw_collectionLink || sc_apw_collectionLink=="") {
							this.classList.toggle("sc_apw_collectionGallery_imageEnlarge");
							sc_apw_tempEnlargenIDHolder = "sc_apw_collectionEnlargenID_" + this.src;
							this.src = this.id.split("sc_apw_collectionEnlargenID_")[1];
							this.id = sc_apw_tempEnlargenIDHolder;
						} else {window.open(sc_apw_collectionLink, "_self");}
					}
				});
			});
			
			// Reset tag inclusion
			sc_apw_includeTags = [];
		}
	}
}


// ----------------------------------
// ------- ADD GALLERY IMAGES -------
// ----------------------------------
// Add images & elements to page
  if (document.getElementById('sc_apw_gallery')) {
    var sc_apw_gallery = document.getElementById('sc_apw_gallery');
	var sc_apw_galleryInteractionBar = document.createElement("div");
	sc_apw_galleryInteractionBar.id = "sc_apw_galleryInteractionBar";
	sc_apw_gallery.parentNode.insertBefore(sc_apw_galleryInteractionBar, sc_apw_gallery);
    
    // Add user interaction options
	if (sc_apw_userChange_sortTags) {
		var sc_apw_userInteract_sortTags = document.createElement("div");
		sc_apw_userInteract_sortTags.id = "sc_apw_userInteract_sortTags";
		sc_apw_galleryInteractionBar.appendChild(sc_apw_userInteract_sortTags);
		
		// Make tag buttons
		var sc_apw_tagButtonObject;
		var sc_apw_tagButtonArray = [];
		for (sc_apw_i = 0; sc_apw_i < sc_apw_allTags.length; sc_apw_i++) {
			sc_apw_tagButtonObject = document.createElement("button");
			sc_apw_tagButtonObject.class = "sc_apw_tagButton";
			sc_apw_tagButtonObject.title = sc_apw_allTags[sc_apw_i];
			sc_apw_tagButtonObject.innerText = sc_apw_allTags[sc_apw_i];
			sc_apw_tagButtonObject.tabIndex = 0;
			sc_apw_tagButtonArray.push(sc_apw_tagButtonObject);
			sc_apw_userInteract_sortTags.appendChild(sc_apw_tagButtonObject);
		}
		// Give all tag buttons an onclick and onkeydown functions
		sc_apw_tagButtonArray.forEach(button => {
			button.addEventListener('click', function() {
				sc_apw_TagListEdit(this);
			});
		});
	}
	
    var sc_apw_gallery_currentImage;
    var sc_apw_gallery_currentDescription;
    var sc_apw_gallery_clickableImages = [];
    if (sc_apw_userChange_sortOrder) {  // Chronological & Alphabetical image sorting options
      var sc_apw_userInteract_sortOrder = document.createElement("div");
      sc_apw_userInteract_sortOrder.id = "sc_apw_userInteract_sortOrder";
      sc_apw_userInteract_sortOrder.innerHTML = `
        <label for="sc_apw_userInteract_sortOrder_object">` + sc_apw_userChange_sortOrderText + `</label>
        <select name="sc_apw_userInteract_sortOrder_object" id="sc_apw_userInteract_sortOrder_object" onchange="
          sc_apw_sortOrder = this.value;
          sc_apw_AddImages();
        ">
          <option value="auto" selected>Auto</option>
          <option value="newest">Newest</option>
          <option value="oldest">Oldest</option>
          <option value="alpha asc">Alphabetical (Ascending)</option>
          <option value="alpha desc">Alphabetical (Descending)</option>
        </select>
      `;
	  sc_apw_galleryInteractionBar.appendChild(sc_apw_userInteract_sortOrder);
    }
	
	// Search bar
	if (sc_apw_userChange_search) {
		var sc_apw_userInteract_search = document.createElement("div");
		sc_apw_userInteract_search.id = "sc_apw_userInteract_search";
		sc_apw_userInteract_search.innerHTML = `
			<div id="sc_apw_userSearch_date_container">
			<label for="sc_apw_userSearch_date">` + sc_apw_searchElement_dateOnText + `</label>
			<input type="date" id="sc_apw_userSearch_date" name="sc_apw_userSearch_date" onchange="sc_apw_SearchElement_DateRestricter(this.value, 'on')"> 
			</div>
			
			<div id="sc_apw_userSearch_dateAfter_container">
			<label for="sc_apw_userSearch_dateAfter">` + sc_apw_searchElement_dateAfterText + `</label>
			<input type="date" id="sc_apw_userSearch_dateAfter" name="sc_apw_userSearch_dateAfter" onchange="sc_apw_SearchElement_DateRestricter(this.value, 'after')"> 
			</div>
			
			<div id="sc_apw_userSearch_dateBefore_container">
			<label for="sc_apw_userSearch_dateBefore">` + sc_apw_searchElement_dateBeforeText + `</label>
			<input type="date" id="sc_apw_userSearch_dateBefore" name="sc_apw_userSearch_dateBefore" onchange="sc_apw_SearchElement_DateRestricter(this.value, 'before')"> 
			</div>
			<!-- -->
			<div id="sc_apw_userSearch_categoryText_container">
				<div id="sc_apw_userSearch_category_container">
				<label for="sc_apw_userSearch_category">` + sc_apw_searchElement_categoryText + `</label>
				<select name="sc_apw_userSearch_category" id="sc_apw_userSearch_category">
				  <option value="title" selected>Title</option>
				  <option value="description">Description</option>
				  <option value="alt">ALT</option>
				</select>
				</div>
				
				<div id="sc_apw_userSearch_text_container">
				<label for="sc_apw_userSearch_text">` + sc_apw_searchElement_searchText + `</label>
				<input type="text" id="sc_apw_userSearch_text" name="sc_apw_userSearch_text" placeholder="Search">
				</div>
			</div>
			
			<button id="sc_apw_userSearch_submit">` + sc_apw_searchElement_submitText + `</button>
			<button id="sc_apw_userSearch_reset">` + sc_apw_searchElement_resetText + `</button>
		`;
		sc_apw_galleryInteractionBar.appendChild(sc_apw_userInteract_search);
		
		// Attach variables to all inputs
		var sc_apw_searchElement_dateOn = document.getElementById("sc_apw_userSearch_date");
		var sc_apw_searchElement_dateBefore = document.getElementById("sc_apw_userSearch_dateBefore");
		var sc_apw_searchElement_dateAfter = document.getElementById("sc_apw_userSearch_dateAfter");
		var sc_apw_searchElement_category = document.getElementById("sc_apw_userSearch_category");
		var sc_apw_searchElement_searchTerms = document.getElementById("sc_apw_userSearch_text");
		var sc_apw_searchElement_submitButton =  document.getElementById("sc_apw_userSearch_submit");
		var sc_apw_searchElement_resetButton =  document.getElementById("sc_apw_userSearch_reset");
		
		// Restrict date pickers to dates that don't conflict with each other
		function sc_apw_SearchElement_DateRestricter(sc_apw_tempDateRef, sc_apw_tempDateSetting) {
			switch (sc_apw_tempDateSetting) {
				case "on":
					if (sc_apw_tempDateRef == "") {
						sc_apw_searchElement_dateBefore.disabled = false;
						sc_apw_searchElement_dateAfter.disabled = false;
					} else {
						sc_apw_searchElement_dateBefore.disabled = true;
						sc_apw_searchElement_dateAfter.disabled = true;
					}
					break;
				case "before":
					if (sc_apw_tempDateRef == "") {
						sc_apw_searchElement_dateAfter.max = "9999-12-31";
					} else {
						sc_apw_searchElement_dateAfter.max = sc_apw_tempDateRef;
					}
					break;
				case "after":
					if (sc_apw_tempDateRef == "") {
						sc_apw_searchElement_dateBefore.min = "0000-01-01";
					} else {
						sc_apw_searchElement_dateBefore.min = sc_apw_tempDateRef;
					}
					break;
			}
		}
		
		// Give search & reset button an onclick and onkeydown function
		sc_apw_searchElement_submitButton.addEventListener('click', function() {
			sc_apw_AddImages()
		});
		sc_apw_searchElement_resetButton.addEventListener('click', function() {
			sc_apw_searchElement_dateOn.value = "";
			sc_apw_searchElement_dateBefore.value ="";
			sc_apw_searchElement_dateAfter.value = "";
			sc_apw_searchElement_category.value = "title";
			sc_apw_searchElement_searchTerms.value = "";
			sc_apw_AddImages()
		});
		/*sc_apw_searchElement_submitButton.addEventListener('keydown', function(e) {
		  if (e.keyCode == 13) {sc_apw_AddImages()}
		});*/
	}
	
	// Remove empty bar
	if (!sc_apw_galleryInteractionBar.firstChild) {sc_apw_galleryInteractionBar.remove()}
  }
  
  // Make editable gallery array
  var sc_apw_galleryArrayVisible = [];
  // Create CSS Elements
  var sc_apw_imageGallery_CSSAddition = document.createElement("style");
  var sc_apw_imageGallery_CSSMobileAddition = document.createElement("style");
  document.head.appendChild(sc_apw_imageGallery_CSSAddition);
  document.head.appendChild(sc_apw_imageGallery_CSSMobileAddition);
	  if (sc_apw_galleryRowAmount < 1) {sc_apw_galleryRowAmount = 1;} // Set row amount to minimum if lower than 1
	  if (sc_apw_galleryMobileRowAmount < 1) {sc_apw_galleryMobileRowAmount = 1;} // Set row amount to minimum if lower than 1
	  
	  // Adding CSS based on row amount
	  sc_apw_imageGallery_CSSAddition.innerHTML = `#sc_apw_gallery img {width: calc(calc(100% / ` + sc_apw_galleryRowAmount + `) - 10px)}`;
	  sc_apw_imageGallery_CSSMobileAddition.innerHTML = `@media only screen and (max-width: ` + sc_apw_CSSMobileWidth + `) {
		#sc_apw_gallery img {width: calc(calc(100% / ` + sc_apw_galleryMobileRowAmount + `) - 10px) !important}`;
	  sc_apw_imageGallery_CSSMobileAddition.innerHTML = sc_apw_imageGallery_CSSMobileAddition.innerHTML + `}`;
	
  // First call of function to create images if gallery present
   if (document.getElementById('sc_apw_gallery')) {sc_apw_AddImages();}
  


// ----------------------------------
// --- ADD GALLERY IMAGE FUNCTION ---
// ----------------------------------
  function sc_apw_AddImages() {
	  // Reset image gallery
	  sc_apw_galleryArrayVisible = [];
	  for (sc_apw_i=0; sc_apw_i<sc_apw_galleryArray.length; sc_apw_i++) {
		sc_apw_galleryArrayVisible.push(sc_apw_galleryArray[sc_apw_i]);
	  }
	
    // Sort image array IF a valid sort order
	if (sc_apw_sortOrder == "auto") {sc_apw_sortOrder = sc_apw_devSortOrder;}
    switch (sc_apw_sortOrder) {
      case "newest":
        sc_apw_galleryArrayVisible.sort(sc_apw_SortDates);
        break;
      case "oldest":
        sc_apw_galleryArrayVisible.sort(sc_apw_SortDates);
        break;
      case "alpha asc":
        sc_apw_galleryArrayVisible.sort(sc_apw_SortAlpha);
        break;
      case "alpha desc":
        sc_apw_galleryArrayVisible.sort(sc_apw_SortAlpha);
        break;
    }
    
    // If image schedule's true, hide images that are set in the future
    if (sc_apw_hideScheduled) {
      for (sc_apw_i=0; sc_apw_i < sc_apw_galleryArrayVisible.length; sc_apw_i++) {
        if ((new Date() < sc_apw_galleryArrayVisible[sc_apw_i][5])) {
          sc_apw_galleryArrayVisible.splice(sc_apw_i, 1);
          sc_apw_i -= 1;
        }
      }
    }
	
	// Hides any images that don't match the tag filters
	if (sc_apw_userChange_sortTags) {
		for (sc_apw_i=0; sc_apw_i<sc_apw_galleryArrayVisible.length; sc_apw_i++) {
			if (!sc_apw_galleryArrayVisible[sc_apw_i][2] || sc_apw_galleryArrayVisible[sc_apw_i][2]=="") {
				if (sc_apw_includeTags.length > 0) {
				  sc_apw_galleryArrayVisible.splice(sc_apw_i, 1);
				  sc_apw_i -= 1;
				}
			} else if (!sc_apw_TagFilter(sc_apw_galleryArrayVisible[sc_apw_i])) {
			  sc_apw_galleryArrayVisible.splice(sc_apw_i, 1);
			  sc_apw_i -= 1;
			}
		}
	}
	
	// Accesses user search terms if available
	if (sc_apw_userChange_search) {
		for (sc_apw_i=0; sc_apw_i<sc_apw_galleryArrayVisible.length; sc_apw_i++) {
			if (!sc_apw_SearchGallery(sc_apw_galleryArrayVisible[sc_apw_i])) {
			  sc_apw_galleryArrayVisible.splice(sc_apw_i, 1);
			  sc_apw_i -= 1;
			}
		}
	}

	// Changing CSS based on image array amount
	if (sc_apw_galleryRowCSSCorrection) {
	  sc_apw_imageGallery_CSSAddition.innerHTML = `#sc_apw_gallery img {width: calc(calc(100% / ` + sc_apw_galleryRowAmount + `) - 10px)}`;
	  for (sc_apw_i = 0; sc_apw_i < sc_apw_galleryArrayVisible.length % sc_apw_galleryRowAmount; sc_apw_i++) {
		sc_apw_imageGallery_CSSAddition.innerHTML = sc_apw_imageGallery_CSSAddition.innerHTML + `
		  #sc_apw_gallery img:nth-last-child(` + (sc_apw_i + 1) + `) {width: calc(calc(100% / ` + (sc_apw_galleryArrayVisible.length % sc_apw_galleryRowAmount) + `) - 10px);}`;
	  }
	  
	  sc_apw_imageGallery_CSSMobileAddition.innerHTML = `@media only screen and (max-width: ` + sc_apw_CSSMobileWidth + `) {
		#sc_apw_gallery img {width: calc(calc(100% / ` + sc_apw_galleryMobileRowAmount + `) - 10px) !important}`;
	  for (sc_apw_i = 0; sc_apw_i < sc_apw_galleryArrayVisible.length % sc_apw_galleryMobileRowAmount; sc_apw_i++) {
		sc_apw_imageGallery_CSSMobileAddition.innerHTML = sc_apw_imageGallery_CSSMobileAddition.innerHTML + `
		  #sc_apw_gallery img:nth-last-child(` + (sc_apw_i + 1) + `) {width: calc(calc(100% / ` + (sc_apw_galleryArrayVisible.length % sc_apw_galleryMobileRowAmount) + `) - 10px) !important;}`;
	  }
	  sc_apw_imageGallery_CSSMobileAddition.innerHTML = sc_apw_imageGallery_CSSMobileAddition.innerHTML + `}`;
	}
    
	
	// Start adding images to gallery after sorting is finished
    if (document.getElementById('sc_apw_gallery')) {
      // Make sure gallery is empty before entering new items
      sc_apw_gallery.innerHTML = '';
      sc_apw_gallery_clickableImages = [];
      
      // Loop to add each image to the page with its details
      for (sc_apw_i=0; sc_apw_i < sc_apw_galleryArrayVisible.length; sc_apw_i++) {
        sc_apw_gallery_currentImage = document.createElement("img");
		
		// Add a class so the click to enlarge plugin ignores these images 
		sc_apw_gallery_currentImage.classList.add(sc_apw_icep_ignoreClass);
        
        // Image URLs to src
        if (sc_apw_previewImages && sc_apw_galleryArrayVisible[sc_apw_i][6] && sc_apw_galleryArrayVisible[sc_apw_i][6] != "") {
          sc_apw_gallery_currentImage.src = sc_apw_imageFolder + sc_apw_galleryArrayVisible[sc_apw_i][6];
        } else {
          sc_apw_gallery_currentImage.src = sc_apw_imageFolder + sc_apw_galleryArrayVisible[sc_apw_i][0];
        }
        
        // Image ALT
        if (sc_apw_galleryArrayVisible[sc_apw_i][1] && sc_apw_galleryArrayVisible[sc_apw_i][1] != "") {sc_apw_gallery_currentImage.alt = sc_apw_galleryArrayVisible[sc_apw_i][1];}
        
        // Image Title
        if (sc_apw_galleryArrayVisible[sc_apw_i][3] && sc_apw_galleryArrayVisible[sc_apw_i][3] != "") {sc_apw_gallery_currentImage.title = sc_apw_galleryArrayVisible[sc_apw_i][3];}
        
        // Add elements to HTML page
        sc_apw_gallery.appendChild(sc_apw_gallery_currentImage);
        sc_apw_gallery_currentImage.tabIndex = 0;
        // Add img element to clickable image array
        sc_apw_gallery_clickableImages.push(sc_apw_gallery_currentImage);
      }
      
      // Give all images an onclick and onkeydown function
      sc_apw_gallery_clickableImages.forEach(img => {
        img.addEventListener('click', function() {
          sc_apw_imageIndex = sc_apw_gallery_clickableImages.indexOf(this);
          sc_apw_ImageShow();
        });
        img.addEventListener('keydown', function(e) {
          if (e.keyCode == 13) {
            sc_apw_imageIndex = sc_apw_gallery_clickableImages.indexOf(this);
            sc_apw_ImageShow();
          }
        });
      });
	  
	  // If no images are displayed, show text instead
	  if (sc_apw_gallery_clickableImages.length < 1) {
		  sc_apw_gallery.innerHTML = `<p id="sc_apw_emptyGalleryText">` + sc_apw_emptyGalleryText + `</p>`;
	  }
    } else {
      console.log("scWidget_ArtistsPortfolio.js: No Gallery element loaded");
    }
  }


// -----------------------------------
// - MAKE CLICKABLE IMAGE ARRAY WORK -
// -----------------------------------
// Create image overlay element if gallery is present
if (document.getElementById('sc_apw_gallery')) {
	const sc_apw_imageViewer = document.createElement('div');
	  sc_apw_imageViewer.id = "sc_apw_imageViewer";
	  document.body.appendChild(sc_apw_imageViewer);
	  const sc_apw_imageViewerBox = document.createElement('div');
	  sc_apw_imageViewerBox.id = "sc_apw_imageViewerBox";
	  sc_apw_imageViewer.appendChild(sc_apw_imageViewerBox);
	  
	  // Create element that holds the image in the viewer
	  const sc_apw_imageHolder = document.createElement('div');
	  sc_apw_imageHolder.id = "sc_apw_imageHolder";
	  sc_apw_imageHolder.tabIndex = 0;
	  sc_apw_imageViewerBox.appendChild(sc_apw_imageHolder);
	  
	  // Create element that holds the image description in the viewer
	  if (sc_apw_gallery_showInfo) {
		const sc_apw_textHolder = document.createElement('div');
		sc_apw_textHolder.id = "sc_apw_textHolder";
		sc_apw_imageViewer.appendChild(sc_apw_textHolder);
	  }
	  
	  // Create left and right buttons for galleries
	  if (sc_apw_gallery_multipleImage) {
		const sc_apw_galleryPrev = document.createElement('div'), sc_apw_galleryNext = document.createElement('div');
		sc_apw_galleryPrev.id = "sc_apw_galleryPrev"; sc_apw_galleryNext.id = "sc_apw_galleryNext";
		sc_apw_galleryPrev.classList.add("sc_apw_galleryButton"); sc_apw_galleryNext.classList.add("sc_apw_galleryButton");
		sc_apw_imageViewerBox.insertBefore(sc_apw_galleryPrev, sc_apw_imageViewerBox.children[0]); sc_apw_imageViewerBox.appendChild(sc_apw_galleryNext);
	  }


	// Set up 'onclick' function
	var sc_apw_imageIndex = 0;
	var sc_apw_viewerDescription_imgs = [];
	var sc_apw_fullpageLinkHREF ="";

	// Date variables
	var sc_apw_imageDateFormatted = sc_apw_settingImageFormat_Date;
	var sc_apw_imageDateFormat_timeSuffix = "pm";
	var sc_apw_imageDateFormat_hourTwelve;
	var sc_apw_imageDateFormat_minutes;
	var sc_apw_date_monthLong = [
		"January", "February", "March", "April", "May", "June", "July", "August", "September", "October",
		"November", "December"
	  ];

	// Opening image view function
	function sc_apw_ImageShow(sc_apw_num) {
	  // Change image position if given an argument
	  if (sc_apw_num) {
		sc_apw_imageIndex += sc_apw_num;
	  }
	  
	  // Check if clicking on the image should open a new window
	  if (sc_apw_gallery_fullpageLinkRedirect && sc_apw_galleryArrayVisible[sc_apw_imageIndex][7]) {
		window.open(sc_apw_galleryArrayVisible[sc_apw_imageIndex][7]);
	  }
	  
	  // Make viewer visible & focused
	  sc_apw_imageViewer.style.display = "block";
	  sc_apw_imageHolder.focus({focusVisible: false});
	  
	  // Set up which image is displaying
	  sc_apw_imageHolder.style.backgroundImage = 'url(' + sc_apw_imageFolder + sc_apw_galleryArrayVisible[sc_apw_imageIndex][0] + ')';
	  
	  // Set up which text is displaying
	  if (sc_apw_gallery_showInfo) {
		sc_apw_textHolder.innerHTML = "";
		
		// Title
		if(sc_apw_galleryArrayVisible[sc_apw_imageIndex][3] && sc_apw_galleryArrayVisible[sc_apw_imageIndex][3] != "" && sc_apw_gallery_showTitle) {sc_apw_textHolder.innerHTML += `<h1 id="sc_apw_textHolder_title">` + sc_apw_galleryArrayVisible[sc_apw_imageIndex][3] + `</h1>`}
		// Date
		if(sc_apw_galleryArrayVisible[sc_apw_imageIndex][5] && sc_apw_galleryArrayVisible[sc_apw_imageIndex][5] != "" && sc_apw_gallery_showDate) {
		  // Create formatted date text
		  sc_apw_imageDateFormatted = sc_apw_settingImageFormat_Date;
		  sc_apw_imageDateFormatted = sc_apw_FormatDate(sc_apw_imageDateFormatted, sc_apw_galleryArrayVisible[sc_apw_imageIndex][5]);
		  sc_apw_textHolder.innerHTML += `<div id="sc_apw_textHolder_date">` + sc_apw_imageDateFormatted + `</div`;
		}
		
		// Tags
		if(sc_apw_galleryArrayVisible[sc_apw_imageIndex][2] && sc_apw_galleryArrayVisible[sc_apw_imageIndex][2] != "" && sc_apw_gallery_showTags) {
			let sc_apw_tempTagTextHolder = `<div id="sc_apw_textHolder_tags">`;
			for (sc_apw_tii=0; sc_apw_tii<sc_apw_galleryArrayVisible[sc_apw_imageIndex][2].split(" ").length; sc_apw_tii++) {
				sc_apw_tempTagTextHolder += `<span class="sc_apw_textHolder_tagName">` + sc_apw_galleryArrayVisible[sc_apw_imageIndex][2].split(" ")[sc_apw_tii].replaceAll("_", " ") + `</span>`;
			}
			sc_apw_tempTagTextHolder += `</div>`
			sc_apw_textHolder.innerHTML += sc_apw_tempTagTextHolder;
		}
		
		// Description
		if(sc_apw_galleryArrayVisible[sc_apw_imageIndex][4] && sc_apw_galleryArrayVisible[sc_apw_imageIndex][4] != "" && sc_apw_gallery_showDescription) {sc_apw_textHolder.innerHTML += `<div id="sc_apw_textHolder_description">` + sc_apw_galleryArrayVisible[sc_apw_imageIndex][4] + `</div>`}
		
		// External Link 
		if (!sc_apw_gallery_fullpageLinkRedirect && sc_apw_galleryArrayVisible[sc_apw_imageIndex][7]) {
			sc_apw_textHolder.innerHTML += `<a id="sc_apw_textHolder_linkRedirect" href="` + sc_apw_galleryArrayVisible[sc_apw_imageIndex][7] + `">External Link</a>`
		}
			
			// Add image enlarge to images in the description
			if (sc_apw_gallery_descriptionImgs_clickable) {
				sc_apw_viewerDescription_imgs = sc_apw_textHolder.querySelectorAll('img');
				for (sc_apw_vi=0; sc_apw_vi<sc_apw_viewerDescription_imgs.length; sc_apw_vi++) {
					// Give images a cursor on hover
					sc_apw_viewerDescription_imgs[sc_apw_vi].style.cursor = "pointer";
					
					// Give image appropriate ID for enlarge click 
					sc_apw_viewerDescription_imgs[sc_apw_vi].id = "sc_apw_collectionEnlargenID_" + sc_apw_viewerDescription_imgs[sc_apw_vi].src;
					
					// Give image an onclick and onkeydown function
					sc_apw_viewerDescription_imgs[sc_apw_vi].tabIndex = 0;
					var sc_apw_tempEnlargenIDHolder = "";
					sc_apw_viewerDescription_imgs[sc_apw_vi].addEventListener('click', function() {
						this.classList.toggle("sc_apw_collectionGallery_imageEnlarge");
						sc_apw_tempEnlargenIDHolder = "sc_apw_collectionEnlargenID_" + this.src;
						this.src = this.id.split("sc_apw_collectionEnlargenID_")[1];
						this.id = sc_apw_tempEnlargenIDHolder;
					});
					sc_apw_viewerDescription_imgs[sc_apw_vi].addEventListener('keydown', function(e) {
						if (e.keyCode == 13) {
							this.classList.toggle("sc_apw_collectionGallery_imageEnlarge");
							sc_apw_tempEnlargenIDHolder = "sc_apw_collectionEnlargenID_" + this.src;
							this.src = this.id.split("sc_apw_collectionEnlargenID_")[1];
							this.id = sc_apw_tempEnlargenIDHolder;
						}
					});
					// Add a class so the click to enlarge plugin ignores this image 
					sc_apw_viewerDescription_imgs[sc_apw_vi].classList.add(sc_apw_icep_ignoreClass);
				}
			}
		
		// Change height if text is visible or not
		if (sc_apw_textHolder.innerHTML == "") {
			sc_apw_imageViewerBox.classList.add("sc_apw_imageViewerBox_Full");
			sc_apw_textHolder.style.display = "none";
		} else {
			sc_apw_imageViewerBox.classList.remove("sc_apw_imageViewerBox_Full");
			sc_apw_textHolder.style.display = "block";
		}
	  } else {
			sc_apw_imageViewerBox.classList.add("sc_apw_imageViewerBox_Full");
		}
	  
	  // Set up the left and right buttons for the gallery
	  if (sc_apw_gallery_multipleImage){
		if (sc_apw_imageIndex < sc_apw_gallery_clickableImages.length-1) {
		  sc_apw_galleryNext.style.pointerEvents = "auto";
		  sc_apw_galleryNext.classList.remove("sc_apw_galleryButton_disabled");
		} else {
		  sc_apw_galleryNext.style.pointerEvents = "none";
		  sc_apw_galleryNext.classList.add("sc_apw_galleryButton_disabled");
		}
		if (sc_apw_imageIndex > 0) {
		  sc_apw_galleryPrev.style.pointerEvents = "auto";
		  sc_apw_galleryPrev.classList.remove("sc_apw_galleryButton_disabled");
		} else {
		  sc_apw_galleryPrev.style.pointerEvents = "none";
		  sc_apw_galleryPrev.classList.add("sc_apw_galleryButton_disabled");
		}
	  }
	}

	// Set up closing function
	function sc_apw_ImageHide() {
	  sc_apw_imageViewer.style.display = "none";
	  sc_apw_gallery_clickableImages[sc_apw_imageIndex].focus({focusVisible: false});
	}


	// Give image holder an onclick function to hide it if clicked
	sc_apw_imageHolder.addEventListener('click', function() {
	  sc_apw_ImageHide();
	});
	sc_apw_imageHolder.addEventListener('keydown', function(e) {
	  if (e.keyCode == 13) {
		sc_apw_ImageHide();
	  }
	});

	// Give gallery left and right buttons their onclick code
	if (sc_apw_gallery_multipleImage) {
	  sc_apw_galleryPrev.addEventListener('click', function() {
		sc_apw_ImageShow(-1);
	  });
	  sc_apw_galleryNext.addEventListener('click', function() {
		sc_apw_ImageShow(1);
	  });
	}


	// Adds a document listener to allow for image viewer hiding & left / right button clicking for the gallery
	document.addEventListener("keydown", function(e) {
	  if (sc_apw_imageViewer.style.display == "block") {
		if (e.keyCode == 27) {
		  sc_apw_ImageHide();
		} else if (e.keyCode == 37 && sc_apw_imageIndex > 0 && sc_apw_gallery_multipleImage) {
		  sc_apw_ImageShow(-1);
		} else if (e.keyCode == 39 && sc_apw_imageIndex < sc_apw_gallery_clickableImages.length-1 && sc_apw_gallery_multipleImage) {
		  sc_apw_ImageShow(1);
		}
	  }
	});
}


// ---------------------------------
// ---- FORMAT DATES FOR READER ----
// ---------------------------------
  var sc_apw_imageDateFormat_dayEnd = "th";
  function sc_apw_FormatDate(sc_apw_imageDateFormatted, sc_apw_currentImageDate) {
      // Find day's suffix
      sc_apw_imageDateFormat_dayEnd = "th";
      if (10 <= sc_apw_currentImageDate.getDate() && sc_apw_currentImageDate.getDate() <= 19) { // Format Day
        sc_apw_imageDateFormat_dayEnd = "th";
      } else if (sc_apw_currentImageDate.getDate().toString().endsWith("1")) {
        sc_apw_imageDateFormat_dayEnd = "st";
      } else if (sc_apw_currentImageDate.getDate().toString().endsWith("2")) {
        sc_apw_imageDateFormat_dayEnd = "nd";
      } else if (sc_apw_currentImageDate.getDate().toString().endsWith("3")) {
        sc_apw_imageDateFormat_dayEnd = "rd";
      }
      
      // Format time
      sc_apw_imageDateFormat_timeSuffix = "pm";
      sc_apw_imageDateFormat_hourTwelve = sc_apw_currentImageDate.getHours();
      if (sc_apw_imageDateFormat_hourTwelve == 0) {
        sc_apw_imageDateFormat_hourTwelve = "12";
        sc_apw_imageDateFormat_timeSuffix = "am";
      }
      if (sc_apw_imageDateFormat_hourTwelve < 12) {  
        sc_apw_imageDateFormat_timeSuffix = "am";
      } else if (sc_apw_imageDateFormat_hourTwelve > 12) {
        sc_apw_imageDateFormat_hourTwelve = sc_apw_imageDateFormat_hourTwelve - 12;
      }
      if (sc_apw_currentImageDate.getMinutes().toString().length < 2) {sc_apw_imageDateFormat_minutes = "0" + sc_apw_currentImageDate.getMinutes();} 
        else {sc_apw_imageDateFormat_minutes = sc_apw_currentImageDate.getMinutes();}
      
      // Replace Day in date formatting
      sc_apw_imageDateFormatted = sc_apw_imageDateFormatted.replaceAll("DDTH",sc_apw_currentImageDate.getDate() + sc_apw_imageDateFormat_dayEnd);
      sc_apw_imageDateFormatted = sc_apw_imageDateFormatted.replaceAll("DDN",sc_apw_currentImageDate.toLocaleString('en-AU', {weekday: 'long'}));
      sc_apw_imageDateFormatted = sc_apw_imageDateFormatted.replaceAll("DDS",sc_apw_currentImageDate.toLocaleString('en-AU', {weekday: 'short'}));
      sc_apw_imageDateFormatted = sc_apw_imageDateFormatted.replaceAll("DD",sc_apw_currentImageDate.getDate());
      
      // Replace Month in date formatting
      sc_apw_imageDateFormatted = sc_apw_imageDateFormatted.replaceAll("MML",sc_apw_date_monthLong[sc_apw_currentImageDate.getMonth()]);
      sc_apw_imageDateFormatted = sc_apw_imageDateFormatted.replaceAll("MMS",sc_apw_date_monthLong[sc_apw_currentImageDate.getMonth()].substr(0,3));
      sc_apw_imageDateFormatted = sc_apw_imageDateFormatted.replaceAll("MM",sc_apw_currentImageDate.getMonth() + 1);
      
      // Replace Year in date formatting
      sc_apw_imageDateFormatted = sc_apw_imageDateFormatted.replaceAll("YYYY",sc_apw_currentImageDate.getFullYear().toString());
      sc_apw_imageDateFormatted = sc_apw_imageDateFormatted.replaceAll("YY",sc_apw_currentImageDate.getFullYear().toString().substr(2));
      
      // Replace Hour in date formatting
      sc_apw_imageDateFormatted = sc_apw_imageDateFormatted.replaceAll("HHS",sc_apw_imageDateFormat_hourTwelve);
      sc_apw_imageDateFormatted = sc_apw_imageDateFormatted.replaceAll("HH",sc_apw_currentImageDate.getHours());
      
      // Replace Minute and Suffix in date formatting
      sc_apw_imageDateFormatted = sc_apw_imageDateFormatted.replaceAll("MIN",sc_apw_imageDateFormat_minutes);
      sc_apw_imageDateFormatted = sc_apw_imageDateFormatted.replaceAll("XM",sc_apw_imageDateFormat_timeSuffix);
      
      // Return value
      return sc_apw_imageDateFormatted;
  }